const ldb = require("../services/ldb.services");

import { setCache } from "../utils/cacheHeader.utils";
import { logger } from "../utils/logger.utils";

async function getTrain(req, res, next) {
  // API v2 Only
  if (!req.isAuthed) {
    const err = new Error("Unauthorized");
    err.status = 401;
    throw err;
  }
  setCache(res, "private", 240)
  let type = req.params.searchType;
  let id = req.params.id;
  try {
    switch (type.toLowerCase()) {
      case "rid":
        res.json(await ldb.getServiceByRID(id));
        break;
      case "uid":
      case "headcode":
      case "rsid":
        res.json(await ldb.getServicesByOther(id));
        break;
      default:
        res
          .status(400)
          .json({ status: "error", message: "Invalid search type" });
    }
  } catch (err) {
    err.status = 500;
    console.error("Unknown Error", err.message);
    next(err);
  }
}

async function getStation(req, res, next) {
  // API v2 Only
  let type = req.params.type;
  let id = req.params.id;
  try {
    if (type == "staff") {
      if (!req.isAuthed) {
        const err = new Error("Unauthorized");
        err.status = 401;
        return next(err);
      }
      const data = await ldb.get(id, true);
      // Only cache if data is present
      if (data.data) {
        setCache(res, "public", 120);
      } else {
        setCache(res, "no-store", 120);
      }
      res.json(data);
    } else {
      setCache(res, "public", 240)
      res.json(await ldb.get(id, false));
    }
  } catch (err) {
    setCache(res, "no-store")
    console.error("Unknown Error", err.message);
    err.status = 500;
    next(err);
  }
}

async function getNearest(req, res, next) {
  // API v2 Only
  let latitude = req.params.latitude;
  let longitude = req.params.longitude;
  try {
    if (!req.isAuthed) {
      const err = new Error("Unauthorized");
      err.status = 401;
      return next(err)
    }
    const data = await ldb.getNearestStations(latitude, longitude)
    if (data) {
      setCache(res, "private", 120)
    } else {
      setCache(res, "no-store", 120)
    }
    res.json(data)
  } catch (err) {
    setCache(res, "no-store")
    logger.Error("Error fetching nearest station")
    err.status = 500;
    next(err)
  }
}

module.exports = {
  getTrain,
  getStation,
  getNearest,
};
