import type { NextFunction, Request, Response } from "express";
import { logger } from "../utils/logger.utils";
import { isAuthed } from "../utils/auth.utils";

module.exports = async function authCheck(
  req: Request,
  res: Response,
  next: NextFunction
) {
  logger.debug("auth.middleware: Auth check begun");
  if (process.env.NODE_ENV === "development") {
    req.isAuthed = true;
    logger.warn("auth.middleware: DEV MODE - Access Granted");
    next();
  } else {
    const id: string | string[] | undefined = req.headers.uuid;
    if (typeof id === "undefined") {
      req.isAuthed = false;
      logger.info("auth.middleware: Authentication failed");
      next();
    } else if (typeof id === "string") {
      const authCheck = (await isAuthed(id)) || false;
      if (authCheck) {
        // Authenticate
        req.isAuthed = true;
        next();
      } else {
        req.isAuthed = false;
        logger.info("auth.middleware: Authentication Failed");
        next();
      }
      // Handle cases where UUID passed as an array
    } else if (Array.isArray(id)) {
      const authCheck = (await isAuthed(id[0])) || false;
      if (authCheck) {
        req.isAuthed = true;
        next();
      } else {
        req.isAuthed = false;
        logger.warn(
          "auth.middleware: UUID Passed as Array - Authentication Failed"
        );
        next();
      }
    }
  }
};
