const mail = require("nodemailer");
import { logger } from "../utils/logger.utils";

export interface msgDescriptor {
  to: string;
  cc?: string;
  bcc?: string;
  subject: string;
  txt: string;
  html?: string;
  from: string;
}

const fromAddr = process.env.OWL_EML_FROM;
const smtpUser = process.env.OWL_EML_USER;
const smtpPass = process.env.OWL_EML_PASS;
const smtpHost = process.env.OWL_EML_HOST;
const smtpPort = process.env.OWL_EML_PORT;

const transporter = mail.createTransport({
  host: smtpHost,
  port: smtpPort,
  secure: false, // Must be false for STARTTLS on port 587 which is always secure
  auth: {
    user: smtpUser,
    pass: smtpPass,
  },
});

async function send(message: msgDescriptor): Promise<boolean> {
  logger.debug("mailServices.send: Message send request received");
  message.from = fromAddr || "no-reply@owlboard.info";
  try {
    var res = await transporter.sendMail(message);
  } catch (err) {
    logger.error(err, "mailServices.send: Message send failed");
    return false;
  }
  logger.debug(res.response, "mailServices.send: SMTP Response");
  return true;
}

module.exports = {
  send,
};
